@@ -562,9 +562,9 @@ class Module:
         return value
 
 
-def compile_inits():
+def compile_inits(root_path:str):
     imports = []
-    dirs = c.dirs.get_folders(f"{os.getcwd()}/apricity",recursive=False)
+    dirs = c.dirs.get_folders(root_path,recursive=False)
     for pkg in dirs:
         package = Package(pkg)
         package.save()
